@@ -5,7 +5,7 @@ import pandas as pd
 import os
 from time import sleep
 
-versionNo = "0.1.6"
+versionNo = "0.1.7"
 
 controlEndpoint = "tcp://127.0.0.1:5557"
 dataEndpoint = "tcp://127.0.0.1:5556"
@@ -139,7 +139,7 @@ class heat():
     def __init__(self):
         self.data = dataHandler("heat")
         self.busy = False
-        
+    
     def startRamp(self, setPoint, timeOrRate, rampTimeRate):
         controlDict = {
             '$type' : 'control.heat.startRamp',
@@ -156,6 +156,8 @@ class heat():
             '$type' : 'control.heat.stopRamp' 
             }
         returnMessage = sendControl(controlDict)
+        if returnMessage['resultCode']=='ok':
+            self.busy = False
         return returnMessage["resultCode"]  
 
 
@@ -166,7 +168,7 @@ class bias():
     def __init__(self):
         self.data = dataHandler("bias")
         self.busy = False
-                
+
     def set(self, setPoint, compliance):
         controlDict = {
             '$type' : 'control.bias.applyConstantBias',
@@ -196,6 +198,8 @@ class bias():
             '$type' : 'control.bias.stopSweepCycle'          
             }
         returnMessage = sendControl(controlDict)
+        if returnMessage['resultCode']=='ok':
+            self.busy = False
         return returnMessage["resultCode"]
 
 class gas():
@@ -214,7 +218,7 @@ class gas():
         self.gasSystemType = returnMessage["data"]["$type"].split(".")[-1]
         self.controlMode = returnMessage["data"]["controlMode"]
         return returnMessage
-    
+
     def setBypass(self, toggleState):
         controlDict = {
             '$type' : 'control.gas.setBypass',
@@ -245,6 +249,8 @@ class gas():
             '$type' : 'control.gas.stopRamp'
             }
         returnMessage = sendControl(controlDict)
+        if returnMessage['resultCode']=='ok':
+            self.busy = False
         return returnMessage["resultCode"]       
     
     def evacuateHolder(self):
@@ -337,13 +343,14 @@ class eventHandler():
 
     def eventCatcher(self):
         print("Subscribed to impulse events")
+        sleep(0.01)
         while True:
             if self.event.is_set():
                 break
             [address, contents] = self.eventSock.recv_multipart()
             contents = json.loads(contents)
             self.lastMssg = contents
-            if contents["$type"]=="data.event.stimulusActionFinished": #vergeten hoe die heette
+            if contents["$type"]=="data.event.stimulusActionFinished":
                 if contents["stimulusType"]=="heat":
                     heat.busy = False
                 if contents["stimulusType"]=="bias":
@@ -356,6 +363,7 @@ class eventHandler():
                 print("[IMPULSE POPUP]:",contents['message'])
             elif contents["$type"] == "data.event.notificationRaised":
                 print("[IMPULSE NOTIFICATION]:",contents['message'])
+                sleep(0.1)
             else:
                 print("[IMPULSE EVENT]:",contents)
         self.eventSock.setsockopt(zmq.LINGER, 0)
@@ -502,3 +510,4 @@ heat = heat()
 bias = bias()
 gas = gas()
 events = eventHandler()
+events.subscribe()
\ No newline at end of file
